{
	"name" : "Charts of Accounts",
	"version" : "1.1",
	"depends" : ["account"],
	"author" : "Tiny",
	"description": """Remove minimal account chart""",
	"website" : "http://tinyerp.com/module_account.html",
	"category" : "Generic Modules/Accounting",
	"init_xml" : [
	],
	"demo_xml" : [
	],
	"update_xml" : [
# Must be loaded by each modules
#		"account_chart.xml",
	],
	"installable": True
}
